==> gnucash-2.6.14-1-x86_64.pkg.tar.xz: usr/lib/gnucash/scm/ccache/2.0/gnucash/gnc-module.go <==
GOOF----LE-8-2.0      ] d 4  h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  
gnc-module	 		g  filenameS	
f  gnc-module.scm	g  set-current-module	 	
 	g  load-extension	f  
libgnc-module	f  scm_init_sw_gnc_module_module	g  process-use-modules	 	 	g  
sw_gnc_module	 	 	g  gnc-module-system-init	g  gnc:module-system-init	g  gnc-module-system-refresh	g  gnc:module-system-refresh	g  gnc-module-load	g  gnc:module-load	g  gnc-module-load-optional	g  gnc:module-load-optional	g  gnc-module-unload	 g  gnc:module-unload	!g  call-with-deferred-observers	"! 	#! 	$g  module-export!	%$ 	&$ 	'g  current-module	(' 	)' 	* 	+ 	, 	- 	.  	/g  gnc:module-begin-syntax	0/ 	1g  make-syntax-transformer	21 	31 	4g  macro	5g  $sc-dispatch	65 	75 	8g  any	9g  each-any	:89	;g  
syntax-object	<g  	eval-when	=g  top	>= 	?g  ribcage	@g  dummy	Ag  form	B@A 	Cg  m-iW7E9c6ubwTYVAFJm6SebL-318	DC= 	ED> 	Ff  l-iW7E9c6ubwTYVAFJm6SebL-323	Gf  l-iW7E9c6ubwTYVAFJm6SebL-324	HFG 	I?BEH 	J? 	Kg  x	LK 	MD 	Nf  l-iW7E9c6ubwTYVAFJm6SebL-320	ON 	P?LMO 	Q>IJP 	Rg  hygiene	SR 	T;<QS 	Ug  load	V;UQS 	Wg  compile	X;WQS 	Yg  eval	Z;YQS 	[g  expand	\;[QS 	]VXZ\ 	^g  begin	_;^QS 	`g  syntax-violation	a` 	b` 	cf  -source expression failed to match any patternC 5      h     ]4	
5 4
 >  "  G   4i>  "  G  4 >  "  G  iRiRiRiRi R4#&)* h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	.
 		
   C>  "  G  4#&)+      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	/
 		
   C>  "  G  4#&),      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	0
 		
   C>  "  G  4#&)-      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	1
 		
   C>  "  G  4#&).      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	2
 		
   C>  "  G  4#&)0      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	3
 		
   C>  "  G  43/47:T]_     h   ?   ] C 7       g  dummy
		 g  form		  			   Cbc  h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  gnc-module.scm
	8	 		"  g  
macro-typeg  syntax-rulesg  patternsg  formg  ...   C5/RC       g  m
	
	$  g  filenamef  gnc-module.scm		
	%	"		+	"		-	"	&	2	"		;	&
	V	(
	]	)
	d	*
	k	+
	r	,
	s	.
 	/
^	0
	1
N	2
	3
 	
   C6 

==> gnucash-2.6.15-1-x86_64.pkg.tar.xz: usr/lib/gnucash/scm/ccache/2.0/gnucash/gnc-module.go <==
GOOF----LE-8-2.0      ] d 4  h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  
gnc-module	 		g  filenameS	
f  gnc-module.scm	g  set-current-module	 	
 	g  load-extension	f  
libgnc-module	f  scm_init_sw_gnc_module_module	g  process-use-modules	 	 	g  
sw_gnc_module	 	 	g  gnc-module-system-init	g  gnc:module-system-init	g  gnc-module-system-refresh	g  gnc:module-system-refresh	g  gnc-module-load	g  gnc:module-load	g  gnc-module-load-optional	g  gnc:module-load-optional	g  gnc-module-unload	 g  gnc:module-unload	!g  call-with-deferred-observers	"! 	#! 	$g  module-export!	%$ 	&$ 	'g  current-module	(' 	)' 	* 	+ 	, 	- 	.  	/g  gnc:module-begin-syntax	0/ 	1g  make-syntax-transformer	21 	31 	4g  macro	5g  $sc-dispatch	65 	75 	8g  any	9g  each-any	:89	;g  
syntax-object	<g  	eval-when	=g  top	>= 	?g  ribcage	@g  dummy	Ag  form	B@A 	Cg  m-4gq1@CjIscgiFd3fOL2$@s-318	DC= 	ED> 	Ff  l-4gq1@CjIscgiFd3fOL2$@s-323	Gf  l-4gq1@CjIscgiFd3fOL2$@s-324	HFG 	I?BEH 	J? 	Kg  x	LK 	MD 	Nf  l-4gq1@CjIscgiFd3fOL2$@s-320	ON 	P?LMO 	Q>IJP 	Rg  hygiene	SR 	T;<QS 	Ug  load	V;UQS 	Wg  compile	X;WQS 	Yg  eval	Z;YQS 	[g  expand	\;[QS 	]VXZ\ 	^g  begin	_;^QS 	`g  syntax-violation	a` 	b` 	cf  -source expression failed to match any patternC 5      h     ]4	
5 4
 >  "  G   4i>  "  G  4 >  "  G  iRiRiRiRi R4#&)* h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	.
 		
   C>  "  G  4#&)+      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	/
 		
   C>  "  G  4#&),      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	0
 		
   C>  "  G  4#&)-      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	1
 		
   C>  "  G  4#&).      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	2
 		
   C>  "  G  4#&)0      h   @   ] 45 6   8       g  filenamef  gnc-module.scm
	3
 		
   C>  "  G  43/47:T]_     h   ?   ] C 7       g  dummy
		 g  form		  			   Cbc  h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  gnc-module.scm
	8	 		"  g  
macro-typeg  syntax-rulesg  patternsg  formg  ...   C5/RC       g  m
	
	$  g  filenamef  gnc-module.scm		
	%	"		+	"		-	"	&	2	"		;	&
	V	(
	]	)
	d	*
	k	+
	r	,
	s	.
 	/
^	0
	1
N	2
	3
 	
   C6 
